aboutsummaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorNebuleon Fumika2012-12-21 01:44:57 -0500
committerNebuleon Fumika2012-12-21 01:44:57 -0500
commit3972512b2a5c25236ea3ba586621dba6e5b56361 (patch)
tree8488a8a86d589f26f770fe1ff930736fb52fce06 /source
parent5585c035fbec86ee4bec79865357479142e94b9f (diff)
downloadsnes9x2005-3972512b2a5c25236ea3ba586621dba6e5b56361.tar.gz
snes9x2005-3972512b2a5c25236ea3ba586621dba6e5b56361.tar.bz2
snes9x2005-3972512b2a5c25236ea3ba586621dba6e5b56361.zip
Looks like only having 'lang' crashes the options dialog. Restore the array of pointers.
Diffstat (limited to 'source')
-rw-r--r--source/nds/gui.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/nds/gui.c b/source/nds/gui.c
index 2f9e1d2..bf85b67 100644
--- a/source/nds/gui.c
+++ b/source/nds/gui.c
@@ -49,6 +49,8 @@ char *lang[3] =
"Français", // 2
};
+char *language_options[] = { (char *) &lang[0], (char *) &lang[1], (char *) &lang[2] };
+
/******************************************************************************
* Macro definition
******************************************************************************/
@@ -3117,8 +3119,8 @@ u32 menu(u16 *screen)
//CPU speed
/* 01 */ NUMERIC_SELECTION_OPTION(NULL, &msg[MSG_SUB_MENU_42], &clock_speed_number, 6, NULL, 1),
- /* 02 */ STRING_SELECTION_OPTION(language_set, NULL, &msg[MSG_SUB_MENU_41], lang,
- &emu_config.language, sizeof(lang) / sizeof(lang[0]) /* number of possible languages */, NULL, ACTION_TYPE, 2),
+ /* 02 */ STRING_SELECTION_OPTION(language_set, NULL, &msg[MSG_SUB_MENU_41], language_options,
+ &emu_config.language, sizeof(language_options) / sizeof(language_options[0]) /* number of possible languages */, NULL, ACTION_TYPE, 2),
/* 03 */ STRING_SELECTION_OPTION(NULL, show_card_space, &msg[MSG_SUB_MENU_43], NULL,
&desert, 2, NULL, PASSIVE_TYPE | HIDEN_TYPE, 3),